From dabcc26b46212e5bfa77479d1b5c274088b78adc Mon Sep 17 00:00:00 2001
From: Olav Morken <olav.morken@uninett.no>
Date: Fri, 23 Dec 2011 07:00:45 +0000
Subject: [PATCH] Fix misspelling "unsoliced" => "unsolicited".

Thanks to Thijs Kinkhorst for fixing this!

git-svn-id: https://simplesamlphp.googlecode.com/svn/trunk@3005 44740490-163a-0410-bde0-09ae8108e29a
---
 lib/SimpleSAML/Auth/Default.php     | 4 ++--
 modules/saml/lib/Auth/Source/SP.php | 4 ++--
 modules/saml/www/sp/saml1-acs.php   | 2 +-
 modules/saml/www/sp/saml2-acs.php   | 4 ++--
 4 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/modules/saml/lib/Auth/Source/SP.php b/modules/saml/lib/Auth/Source/SP.php
index fd2536f83..9f39475d6 100644
--- a/modules/saml/lib/Auth/Source/SP.php
+++ b/modules/saml/lib/Auth/Source/SP.php
@@ -502,13 +502,13 @@ class sspmod_saml_Auth_Source_SP extends SimpleSAML_Auth_Source {
 
 		$state['Attributes'] = $authProcState['Attributes'];
 
-		if (isset($state['saml:sp:isUnsoliced']) && (bool)$state['saml:sp:isUnsoliced']) {
+		if (isset($state['saml:sp:isUnsolicited']) && (bool)$state['saml:sp:isUnsolicited']) {
 			if (!empty($state['saml:sp:RelayState'])) {
 				$redirectTo = $state['saml:sp:RelayState'];
 			} else {
 				$redirectTo = $source->getMetadata()->getString('RelayState', '/');
 			}
-			SimpleSAML_Auth_Default::handleUnsolicedAuth($sourceId, $state, $redirectTo);
+			SimpleSAML_Auth_Default::handleUnsolicitedAuth($sourceId, $state, $redirectTo);
 		}
 
 		SimpleSAML_Auth_Source::completeAuth($state);
diff --git a/modules/saml/www/sp/saml1-acs.php b/modules/saml/www/sp/saml1-acs.php
index cc42502b8..28ba71143 100644
--- a/modules/saml/www/sp/saml1-acs.php
+++ b/modules/saml/www/sp/saml1-acs.php
@@ -24,7 +24,7 @@ $target = (string)$_REQUEST['TARGET'];
 if (preg_match('@^https?://@i', $target)) {
 	/* Unsolicited response. */
 	$state = array(
-		'saml:sp:isUnsoliced' => TRUE,
+		'saml:sp:isUnsolicited' => TRUE,
 		'saml:sp:AuthId' => $sourceId,
 		'saml:sp:RelayState' => $target,
 	);
diff --git a/lib/SimpleSAML/Auth/Default.php b/lib/SimpleSAML/Auth/Default.php
index e8a07e12c..c2e11c4d9 100644
--- a/lib/SimpleSAML/Auth/Default.php
+++ b/lib/SimpleSAML/Auth/Default.php
@@ -232,7 +232,7 @@ class SimpleSAML_Auth_Default {
 
 
 	/**
 	 * Handle a unsoliced login operations.
 	 *
 	 * This function creates a session from the received information. It
 	 * will then redirect to the given URL.
@@ -244,7 +244,7 @@ class SimpleSAML_Auth_Default {
 	 * @param string $redirectTo  The URL we should redirect the user to after
 	 *                            updating the session.
 	 */
-	public static function handleUnsolicedAuth($authId, array $state, $redirectTo) {
+	public static function handleUnsolicitedAuth($authId, array $state, $redirectTo) {
 		assert('is_string($authId)');
 		assert('is_string($redirectTo)');
 
@@ -232,7 +232,7 @@ class SimpleSAML_Auth_Default {
 
 	/**
-	 * Handle a unsoliced login operations.
+	 * Handle a unsolicited login operations.
 	 *
 	 * This function creates a session from the received information. It
diff --git a/modules/saml/www/sp/saml2-acs.php b/modules/saml/www/sp/saml2-acs.php
index b4abb30f4..dd112c3f0 100644
--- a/modules/saml/www/sp/saml2-acs.php
+++ b/modules/saml/www/sp/saml2-acs.php
@@ -43,9 +43,9 @@ if (!empty($stateId)) {
 		throw new SimpleSAML_Error_Exception('The authentication source id in the URL does not match the authentication source which sent the request.');
 	}
 } else {
 	/* This is an unsoliced response. */
 	$state = array(
-		'saml:sp:isUnsoliced' => TRUE,
+		'saml:sp:isUnsolicited' => TRUE,
 		'saml:sp:AuthId' => $sourceId,
 		'saml:sp:RelayState' => $response->getRelayState(),
 	);
@@ -43,9 +43,9 @@ if (!empty($stateId)) {
 	}
 } else {
-	/* This is an unsoliced response. */
+	/* This is an unsolicited response. */
 	$state = array(
-- 
GitLab